@@ -25,6 +25,7 @@ from .type_defs import (
     DescribeJournalKinesisStreamResponseTypeDef,
     DescribeJournalS3ExportResponseTypeDef,
     DescribeLedgerResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     ExportJournalToS3ResponseTypeDef,
     GetBlockResponseTypeDef,
     GetDigestResponseTypeDef,
@@ -114,7 +115,7 @@ class QLDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_qldb/client/#create_ledger)
         """
 
-    def delete_ledger(self, *, Name: str) -> None:
+    def delete_ledger(self, *, Name: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a ledger and all of its contents.
 
@@ -159,7 +160,7 @@ class QLDBClient(BaseClient):
         Name: str,
         InclusiveStartTime: Union[datetime, str],
         ExclusiveEndTime: Union[datetime, str],
-        S3ExportConfiguration: "S3ExportConfigurationTypeDef",
+        S3ExportConfiguration: S3ExportConfigurationTypeDef,
         RoleArn: str,
         OutputFormat: OutputFormatType = ...
     ) -> ExportJournalToS3ResponseTypeDef:
@@ -189,8 +190,8 @@ class QLDBClient(BaseClient):
         self,
         *,
         Name: str,
-        BlockAddress: "ValueHolderTypeDef",
-        DigestTipAddress: "ValueHolderTypeDef" = ...
+        BlockAddress: ValueHolderTypeDef,
+        DigestTipAddress: ValueHolderTypeDef = ...
     ) -> GetBlockResponseTypeDef:
         """
         Returns a block object at a specified address in a journal.
@@ -211,9 +212,9 @@ class QLDBClient(BaseClient):
         self,
         *,
         Name: str,
-        BlockAddress: "ValueHolderTypeDef",
+        BlockAddress: ValueHolderTypeDef,
         DocumentId: str,
-        DigestTipAddress: "ValueHolderTypeDef" = ...
+        DigestTipAddress: ValueHolderTypeDef = ...
     ) -> GetRevisionResponseTypeDef:
         """
         Returns a revision data object for a specified document ID and block address.
@@ -279,7 +280,7 @@ class QLDBClient(BaseClient):
         LedgerName: str,
         RoleArn: str,
         InclusiveStartTime: Union[datetime, str],
-        KinesisConfiguration: "KinesisConfigurationTypeDef",
+        KinesisConfiguration: KinesisConfigurationTypeDef,
         StreamName: str,
         Tags: Mapping[str, str] = ...,
         ExclusiveEndTime: Union[datetime, str] = ...
