@@ -34,51 +34,52 @@ else:
 
 __all__ = (
     "CancelJournalKinesisStreamRequestRequestTypeDef",
-    "CancelJournalKinesisStreamResponseTypeDef",
+    "ResponseMetadataTypeDef",
     "CreateLedgerRequestRequestTypeDef",
-    "CreateLedgerResponseTypeDef",
     "DeleteLedgerRequestRequestTypeDef",
     "DescribeJournalKinesisStreamRequestRequestTypeDef",
-    "DescribeJournalKinesisStreamResponseTypeDef",
     "DescribeJournalS3ExportRequestRequestTypeDef",
-    "DescribeJournalS3ExportResponseTypeDef",
     "DescribeLedgerRequestRequestTypeDef",
-    "DescribeLedgerResponseTypeDef",
-    "ExportJournalToS3RequestRequestTypeDef",
+    "LedgerEncryptionDescriptionTypeDef",
+    "ValueHolderTypeDef",
+    "GetDigestRequestRequestTypeDef",
+    "KinesisConfigurationTypeDef",
+    "LedgerSummaryTypeDef",
+    "ListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
+    "ListJournalS3ExportsForLedgerRequestRequestTypeDef",
+    "ListJournalS3ExportsRequestRequestTypeDef",
+    "ListLedgersRequestRequestTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "S3EncryptionConfigurationTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateLedgerPermissionsModeRequestRequestTypeDef",
+    "UpdateLedgerRequestRequestTypeDef",
+    "CancelJournalKinesisStreamResponseTypeDef",
+    "CreateLedgerResponseTypeDef",
+    "EmptyResponseMetadataTypeDef",
     "ExportJournalToS3ResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "StreamJournalToKinesisResponseTypeDef",
+    "UpdateLedgerPermissionsModeResponseTypeDef",
+    "DescribeLedgerResponseTypeDef",
+    "UpdateLedgerResponseTypeDef",
     "GetBlockRequestRequestTypeDef",
     "GetBlockResponseTypeDef",
-    "GetDigestRequestRequestTypeDef",
     "GetDigestResponseTypeDef",
     "GetRevisionRequestRequestTypeDef",
     "GetRevisionResponseTypeDef",
     "JournalKinesisStreamDescriptionTypeDef",
-    "JournalS3ExportDescriptionTypeDef",
-    "KinesisConfigurationTypeDef",
-    "LedgerEncryptionDescriptionTypeDef",
-    "LedgerSummaryTypeDef",
-    "ListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
-    "ListJournalKinesisStreamsForLedgerResponseTypeDef",
-    "ListJournalS3ExportsForLedgerRequestRequestTypeDef",
-    "ListJournalS3ExportsForLedgerResponseTypeDef",
-    "ListJournalS3ExportsRequestRequestTypeDef",
-    "ListJournalS3ExportsResponseTypeDef",
-    "ListLedgersRequestRequestTypeDef",
-    "ListLedgersResponseTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "ResponseMetadataTypeDef",
-    "S3EncryptionConfigurationTypeDef",
-    "S3ExportConfigurationTypeDef",
     "StreamJournalToKinesisRequestRequestTypeDef",
-    "StreamJournalToKinesisResponseTypeDef",
-    "TagResourceRequestRequestTypeDef",
-    "UntagResourceRequestRequestTypeDef",
-    "UpdateLedgerPermissionsModeRequestRequestTypeDef",
-    "UpdateLedgerPermissionsModeResponseTypeDef",
-    "UpdateLedgerRequestRequestTypeDef",
-    "UpdateLedgerResponseTypeDef",
-    "ValueHolderTypeDef",
+    "ListLedgersResponseTypeDef",
+    "S3ExportConfigurationTypeDef",
+    "DescribeJournalKinesisStreamResponseTypeDef",
+    "ListJournalKinesisStreamsForLedgerResponseTypeDef",
+    "ExportJournalToS3RequestRequestTypeDef",
+    "JournalS3ExportDescriptionTypeDef",
+    "DescribeJournalS3ExportResponseTypeDef",
+    "ListJournalS3ExportsForLedgerResponseTypeDef",
+    "ListJournalS3ExportsResponseTypeDef",
 )
 
 CancelJournalKinesisStreamRequestRequestTypeDef = TypedDict(
@@ -89,11 +90,14 @@ CancelJournalKinesisStreamRequestRequestTypeDef = TypedDict(
     },
 )
 
-CancelJournalKinesisStreamResponseTypeDef = TypedDict(
-    "CancelJournalKinesisStreamResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "StreamId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -121,20 +125,6 @@ class CreateLedgerRequestRequestTypeDef(
     pass
 
 
-CreateLedgerResponseTypeDef = TypedDict(
-    "CreateLedgerResponseTypeDef",
-    {
-        "Name": str,
-        "Arn": str,
-        "State": LedgerStateType,
-        "CreationDateTime": datetime,
-        "PermissionsMode": PermissionsModeType,
-        "DeletionProtection": bool,
-        "KmsKeyArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DeleteLedgerRequestRequestTypeDef = TypedDict(
     "DeleteLedgerRequestRequestTypeDef",
     {
@@ -150,14 +140,6 @@ DescribeJournalKinesisStreamRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeJournalKinesisStreamResponseTypeDef = TypedDict(
-    "DescribeJournalKinesisStreamResponseTypeDef",
-    {
-        "Stream": "JournalKinesisStreamDescriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeJournalS3ExportRequestRequestTypeDef = TypedDict(
     "DescribeJournalS3ExportRequestRequestTypeDef",
     {
@@ -166,14 +148,6 @@ DescribeJournalS3ExportRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeJournalS3ExportResponseTypeDef = TypedDict(
-    "DescribeJournalS3ExportResponseTypeDef",
-    {
-        "ExportDescription": "JournalS3ExportDescriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeLedgerRequestRequestTypeDef = TypedDict(
     "DescribeLedgerRequestRequestTypeDef",
     {
@@ -181,211 +155,6 @@ DescribeLedgerRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeLedgerResponseTypeDef = TypedDict(
-    "DescribeLedgerResponseTypeDef",
-    {
-        "Name": str,
-        "Arn": str,
-        "State": LedgerStateType,
-        "CreationDateTime": datetime,
-        "PermissionsMode": PermissionsModeType,
-        "DeletionProtection": bool,
-        "EncryptionDescription": "LedgerEncryptionDescriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredExportJournalToS3RequestRequestTypeDef = TypedDict(
-    "_RequiredExportJournalToS3RequestRequestTypeDef",
-    {
-        "Name": str,
-        "InclusiveStartTime": Union[datetime, str],
-        "ExclusiveEndTime": Union[datetime, str],
-        "S3ExportConfiguration": "S3ExportConfigurationTypeDef",
-        "RoleArn": str,
-    },
-)
-_OptionalExportJournalToS3RequestRequestTypeDef = TypedDict(
-    "_OptionalExportJournalToS3RequestRequestTypeDef",
-    {
-        "OutputFormat": OutputFormatType,
-    },
-    total=False,
-)
-
-
-class ExportJournalToS3RequestRequestTypeDef(
-    _RequiredExportJournalToS3RequestRequestTypeDef, _OptionalExportJournalToS3RequestRequestTypeDef
-):
-    pass
-
-
-ExportJournalToS3ResponseTypeDef = TypedDict(
-    "ExportJournalToS3ResponseTypeDef",
-    {
-        "ExportId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredGetBlockRequestRequestTypeDef = TypedDict(
-    "_RequiredGetBlockRequestRequestTypeDef",
-    {
-        "Name": str,
-        "BlockAddress": "ValueHolderTypeDef",
-    },
-)
-_OptionalGetBlockRequestRequestTypeDef = TypedDict(
-    "_OptionalGetBlockRequestRequestTypeDef",
-    {
-        "DigestTipAddress": "ValueHolderTypeDef",
-    },
-    total=False,
-)
-
-
-class GetBlockRequestRequestTypeDef(
-    _RequiredGetBlockRequestRequestTypeDef, _OptionalGetBlockRequestRequestTypeDef
-):
-    pass
-
-
-GetBlockResponseTypeDef = TypedDict(
-    "GetBlockResponseTypeDef",
-    {
-        "Block": "ValueHolderTypeDef",
-        "Proof": "ValueHolderTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-GetDigestRequestRequestTypeDef = TypedDict(
-    "GetDigestRequestRequestTypeDef",
-    {
-        "Name": str,
-    },
-)
-
-GetDigestResponseTypeDef = TypedDict(
-    "GetDigestResponseTypeDef",
-    {
-        "Digest": bytes,
-        "DigestTipAddress": "ValueHolderTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredGetRevisionRequestRequestTypeDef = TypedDict(
-    "_RequiredGetRevisionRequestRequestTypeDef",
-    {
-        "Name": str,
-        "BlockAddress": "ValueHolderTypeDef",
-        "DocumentId": str,
-    },
-)
-_OptionalGetRevisionRequestRequestTypeDef = TypedDict(
-    "_OptionalGetRevisionRequestRequestTypeDef",
-    {
-        "DigestTipAddress": "ValueHolderTypeDef",
-    },
-    total=False,
-)
-
-
-class GetRevisionRequestRequestTypeDef(
-    _RequiredGetRevisionRequestRequestTypeDef, _OptionalGetRevisionRequestRequestTypeDef
-):
-    pass
-
-
-GetRevisionResponseTypeDef = TypedDict(
-    "GetRevisionResponseTypeDef",
-    {
-        "Proof": "ValueHolderTypeDef",
-        "Revision": "ValueHolderTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredJournalKinesisStreamDescriptionTypeDef = TypedDict(
-    "_RequiredJournalKinesisStreamDescriptionTypeDef",
-    {
-        "LedgerName": str,
-        "RoleArn": str,
-        "StreamId": str,
-        "Status": StreamStatusType,
-        "KinesisConfiguration": "KinesisConfigurationTypeDef",
-        "StreamName": str,
-    },
-)
-_OptionalJournalKinesisStreamDescriptionTypeDef = TypedDict(
-    "_OptionalJournalKinesisStreamDescriptionTypeDef",
-    {
-        "CreationTime": datetime,
-        "InclusiveStartTime": datetime,
-        "ExclusiveEndTime": datetime,
-        "Arn": str,
-        "ErrorCause": ErrorCauseType,
-    },
-    total=False,
-)
-
-
-class JournalKinesisStreamDescriptionTypeDef(
-    _RequiredJournalKinesisStreamDescriptionTypeDef, _OptionalJournalKinesisStreamDescriptionTypeDef
-):
-    pass
-
-
-_RequiredJournalS3ExportDescriptionTypeDef = TypedDict(
-    "_RequiredJournalS3ExportDescriptionTypeDef",
-    {
-        "LedgerName": str,
-        "ExportId": str,
-        "ExportCreationTime": datetime,
-        "Status": ExportStatusType,
-        "InclusiveStartTime": datetime,
-        "ExclusiveEndTime": datetime,
-        "S3ExportConfiguration": "S3ExportConfigurationTypeDef",
-        "RoleArn": str,
-    },
-)
-_OptionalJournalS3ExportDescriptionTypeDef = TypedDict(
-    "_OptionalJournalS3ExportDescriptionTypeDef",
-    {
-        "OutputFormat": OutputFormatType,
-    },
-    total=False,
-)
-
-
-class JournalS3ExportDescriptionTypeDef(
-    _RequiredJournalS3ExportDescriptionTypeDef, _OptionalJournalS3ExportDescriptionTypeDef
-):
-    pass
-
-
-_RequiredKinesisConfigurationTypeDef = TypedDict(
-    "_RequiredKinesisConfigurationTypeDef",
-    {
-        "StreamArn": str,
-    },
-)
-_OptionalKinesisConfigurationTypeDef = TypedDict(
-    "_OptionalKinesisConfigurationTypeDef",
-    {
-        "AggregationEnabled": bool,
-    },
-    total=False,
-)
-
-
-class KinesisConfigurationTypeDef(
-    _RequiredKinesisConfigurationTypeDef, _OptionalKinesisConfigurationTypeDef
-):
-    pass
-
-
 _RequiredLedgerEncryptionDescriptionTypeDef = TypedDict(
     "_RequiredLedgerEncryptionDescriptionTypeDef",
     {
@@ -408,6 +177,42 @@ class LedgerEncryptionDescriptionTypeDef(
     pass
 
 
+ValueHolderTypeDef = TypedDict(
+    "ValueHolderTypeDef",
+    {
+        "IonText": str,
+    },
+    total=False,
+)
+
+GetDigestRequestRequestTypeDef = TypedDict(
+    "GetDigestRequestRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+
+_RequiredKinesisConfigurationTypeDef = TypedDict(
+    "_RequiredKinesisConfigurationTypeDef",
+    {
+        "StreamArn": str,
+    },
+)
+_OptionalKinesisConfigurationTypeDef = TypedDict(
+    "_OptionalKinesisConfigurationTypeDef",
+    {
+        "AggregationEnabled": bool,
+    },
+    total=False,
+)
+
+
+class KinesisConfigurationTypeDef(
+    _RequiredKinesisConfigurationTypeDef, _OptionalKinesisConfigurationTypeDef
+):
+    pass
+
+
 LedgerSummaryTypeDef = TypedDict(
     "LedgerSummaryTypeDef",
     {
@@ -441,15 +246,6 @@ class ListJournalKinesisStreamsForLedgerRequestRequestTypeDef(
     pass
 
 
-ListJournalKinesisStreamsForLedgerResponseTypeDef = TypedDict(
-    "ListJournalKinesisStreamsForLedgerResponseTypeDef",
-    {
-        "Streams": List["JournalKinesisStreamDescriptionTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredListJournalS3ExportsForLedgerRequestRequestTypeDef = TypedDict(
     "_RequiredListJournalS3ExportsForLedgerRequestRequestTypeDef",
     {
@@ -473,15 +269,6 @@ class ListJournalS3ExportsForLedgerRequestRequestTypeDef(
     pass
 
 
-ListJournalS3ExportsForLedgerResponseTypeDef = TypedDict(
-    "ListJournalS3ExportsForLedgerResponseTypeDef",
-    {
-        "JournalS3Exports": List["JournalS3ExportDescriptionTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListJournalS3ExportsRequestRequestTypeDef = TypedDict(
     "ListJournalS3ExportsRequestRequestTypeDef",
     {
@@ -491,15 +278,6 @@ ListJournalS3ExportsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListJournalS3ExportsResponseTypeDef = TypedDict(
-    "ListJournalS3ExportsResponseTypeDef",
-    {
-        "JournalS3Exports": List["JournalS3ExportDescriptionTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListLedgersRequestRequestTypeDef = TypedDict(
     "ListLedgersRequestRequestTypeDef",
     {
@@ -509,15 +287,6 @@ ListLedgersRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListLedgersResponseTypeDef = TypedDict(
-    "ListLedgersResponseTypeDef",
-    {
-        "Ledgers": List["LedgerSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
@@ -525,25 +294,6 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
 _RequiredS3EncryptionConfigurationTypeDef = TypedDict(
     "_RequiredS3EncryptionConfigurationTypeDef",
     {
@@ -565,50 +315,6 @@ class S3EncryptionConfigurationTypeDef(
     pass
 
 
-S3ExportConfigurationTypeDef = TypedDict(
-    "S3ExportConfigurationTypeDef",
-    {
-        "Bucket": str,
-        "Prefix": str,
-        "EncryptionConfiguration": "S3EncryptionConfigurationTypeDef",
-    },
-)
-
-_RequiredStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
-    "_RequiredStreamJournalToKinesisRequestRequestTypeDef",
-    {
-        "LedgerName": str,
-        "RoleArn": str,
-        "InclusiveStartTime": Union[datetime, str],
-        "KinesisConfiguration": "KinesisConfigurationTypeDef",
-        "StreamName": str,
-    },
-)
-_OptionalStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
-    "_OptionalStreamJournalToKinesisRequestRequestTypeDef",
-    {
-        "Tags": Mapping[str, str],
-        "ExclusiveEndTime": Union[datetime, str],
-    },
-    total=False,
-)
-
-
-class StreamJournalToKinesisRequestRequestTypeDef(
-    _RequiredStreamJournalToKinesisRequestRequestTypeDef,
-    _OptionalStreamJournalToKinesisRequestRequestTypeDef,
-):
-    pass
-
-
-StreamJournalToKinesisResponseTypeDef = TypedDict(
-    "StreamJournalToKinesisResponseTypeDef",
-    {
-        "StreamId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
@@ -633,16 +339,6 @@ UpdateLedgerPermissionsModeRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateLedgerPermissionsModeResponseTypeDef = TypedDict(
-    "UpdateLedgerPermissionsModeResponseTypeDef",
-    {
-        "Name": str,
-        "Arn": str,
-        "PermissionsMode": PermissionsModeType,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateLedgerRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateLedgerRequestRequestTypeDef",
     {
@@ -665,6 +361,83 @@ class UpdateLedgerRequestRequestTypeDef(
     pass
 
 
+CancelJournalKinesisStreamResponseTypeDef = TypedDict(
+    "CancelJournalKinesisStreamResponseTypeDef",
+    {
+        "StreamId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateLedgerResponseTypeDef = TypedDict(
+    "CreateLedgerResponseTypeDef",
+    {
+        "Name": str,
+        "Arn": str,
+        "State": LedgerStateType,
+        "CreationDateTime": datetime,
+        "PermissionsMode": PermissionsModeType,
+        "DeletionProtection": bool,
+        "KmsKeyArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ExportJournalToS3ResponseTypeDef = TypedDict(
+    "ExportJournalToS3ResponseTypeDef",
+    {
+        "ExportId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StreamJournalToKinesisResponseTypeDef = TypedDict(
+    "StreamJournalToKinesisResponseTypeDef",
+    {
+        "StreamId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateLedgerPermissionsModeResponseTypeDef = TypedDict(
+    "UpdateLedgerPermissionsModeResponseTypeDef",
+    {
+        "Name": str,
+        "Arn": str,
+        "PermissionsMode": PermissionsModeType,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeLedgerResponseTypeDef = TypedDict(
+    "DescribeLedgerResponseTypeDef",
+    {
+        "Name": str,
+        "Arn": str,
+        "State": LedgerStateType,
+        "CreationDateTime": datetime,
+        "PermissionsMode": PermissionsModeType,
+        "DeletionProtection": bool,
+        "EncryptionDescription": LedgerEncryptionDescriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateLedgerResponseTypeDef = TypedDict(
     "UpdateLedgerResponseTypeDef",
     {
@@ -673,15 +446,250 @@ UpdateLedgerResponseTypeDef = TypedDict(
         "State": LedgerStateType,
         "CreationDateTime": datetime,
         "DeletionProtection": bool,
-        "EncryptionDescription": "LedgerEncryptionDescriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "EncryptionDescription": LedgerEncryptionDescriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-ValueHolderTypeDef = TypedDict(
-    "ValueHolderTypeDef",
+_RequiredGetBlockRequestRequestTypeDef = TypedDict(
+    "_RequiredGetBlockRequestRequestTypeDef",
     {
-        "IonText": str,
+        "Name": str,
+        "BlockAddress": ValueHolderTypeDef,
+    },
+)
+_OptionalGetBlockRequestRequestTypeDef = TypedDict(
+    "_OptionalGetBlockRequestRequestTypeDef",
+    {
+        "DigestTipAddress": ValueHolderTypeDef,
     },
     total=False,
 )
+
+
+class GetBlockRequestRequestTypeDef(
+    _RequiredGetBlockRequestRequestTypeDef, _OptionalGetBlockRequestRequestTypeDef
+):
+    pass
+
+
+GetBlockResponseTypeDef = TypedDict(
+    "GetBlockResponseTypeDef",
+    {
+        "Block": ValueHolderTypeDef,
+        "Proof": ValueHolderTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetDigestResponseTypeDef = TypedDict(
+    "GetDigestResponseTypeDef",
+    {
+        "Digest": bytes,
+        "DigestTipAddress": ValueHolderTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredGetRevisionRequestRequestTypeDef = TypedDict(
+    "_RequiredGetRevisionRequestRequestTypeDef",
+    {
+        "Name": str,
+        "BlockAddress": ValueHolderTypeDef,
+        "DocumentId": str,
+    },
+)
+_OptionalGetRevisionRequestRequestTypeDef = TypedDict(
+    "_OptionalGetRevisionRequestRequestTypeDef",
+    {
+        "DigestTipAddress": ValueHolderTypeDef,
+    },
+    total=False,
+)
+
+
+class GetRevisionRequestRequestTypeDef(
+    _RequiredGetRevisionRequestRequestTypeDef, _OptionalGetRevisionRequestRequestTypeDef
+):
+    pass
+
+
+GetRevisionResponseTypeDef = TypedDict(
+    "GetRevisionResponseTypeDef",
+    {
+        "Proof": ValueHolderTypeDef,
+        "Revision": ValueHolderTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredJournalKinesisStreamDescriptionTypeDef = TypedDict(
+    "_RequiredJournalKinesisStreamDescriptionTypeDef",
+    {
+        "LedgerName": str,
+        "RoleArn": str,
+        "StreamId": str,
+        "Status": StreamStatusType,
+        "KinesisConfiguration": KinesisConfigurationTypeDef,
+        "StreamName": str,
+    },
+)
+_OptionalJournalKinesisStreamDescriptionTypeDef = TypedDict(
+    "_OptionalJournalKinesisStreamDescriptionTypeDef",
+    {
+        "CreationTime": datetime,
+        "InclusiveStartTime": datetime,
+        "ExclusiveEndTime": datetime,
+        "Arn": str,
+        "ErrorCause": ErrorCauseType,
+    },
+    total=False,
+)
+
+
+class JournalKinesisStreamDescriptionTypeDef(
+    _RequiredJournalKinesisStreamDescriptionTypeDef, _OptionalJournalKinesisStreamDescriptionTypeDef
+):
+    pass
+
+
+_RequiredStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
+    "_RequiredStreamJournalToKinesisRequestRequestTypeDef",
+    {
+        "LedgerName": str,
+        "RoleArn": str,
+        "InclusiveStartTime": Union[datetime, str],
+        "KinesisConfiguration": KinesisConfigurationTypeDef,
+        "StreamName": str,
+    },
+)
+_OptionalStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
+    "_OptionalStreamJournalToKinesisRequestRequestTypeDef",
+    {
+        "Tags": Mapping[str, str],
+        "ExclusiveEndTime": Union[datetime, str],
+    },
+    total=False,
+)
+
+
+class StreamJournalToKinesisRequestRequestTypeDef(
+    _RequiredStreamJournalToKinesisRequestRequestTypeDef,
+    _OptionalStreamJournalToKinesisRequestRequestTypeDef,
+):
+    pass
+
+
+ListLedgersResponseTypeDef = TypedDict(
+    "ListLedgersResponseTypeDef",
+    {
+        "Ledgers": List[LedgerSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+S3ExportConfigurationTypeDef = TypedDict(
+    "S3ExportConfigurationTypeDef",
+    {
+        "Bucket": str,
+        "Prefix": str,
+        "EncryptionConfiguration": S3EncryptionConfigurationTypeDef,
+    },
+)
+
+DescribeJournalKinesisStreamResponseTypeDef = TypedDict(
+    "DescribeJournalKinesisStreamResponseTypeDef",
+    {
+        "Stream": JournalKinesisStreamDescriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListJournalKinesisStreamsForLedgerResponseTypeDef = TypedDict(
+    "ListJournalKinesisStreamsForLedgerResponseTypeDef",
+    {
+        "Streams": List[JournalKinesisStreamDescriptionTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredExportJournalToS3RequestRequestTypeDef = TypedDict(
+    "_RequiredExportJournalToS3RequestRequestTypeDef",
+    {
+        "Name": str,
+        "InclusiveStartTime": Union[datetime, str],
+        "ExclusiveEndTime": Union[datetime, str],
+        "S3ExportConfiguration": S3ExportConfigurationTypeDef,
+        "RoleArn": str,
+    },
+)
+_OptionalExportJournalToS3RequestRequestTypeDef = TypedDict(
+    "_OptionalExportJournalToS3RequestRequestTypeDef",
+    {
+        "OutputFormat": OutputFormatType,
+    },
+    total=False,
+)
+
+
+class ExportJournalToS3RequestRequestTypeDef(
+    _RequiredExportJournalToS3RequestRequestTypeDef, _OptionalExportJournalToS3RequestRequestTypeDef
+):
+    pass
+
+
+_RequiredJournalS3ExportDescriptionTypeDef = TypedDict(
+    "_RequiredJournalS3ExportDescriptionTypeDef",
+    {
+        "LedgerName": str,
+        "ExportId": str,
+        "ExportCreationTime": datetime,
+        "Status": ExportStatusType,
+        "InclusiveStartTime": datetime,
+        "ExclusiveEndTime": datetime,
+        "S3ExportConfiguration": S3ExportConfigurationTypeDef,
+        "RoleArn": str,
+    },
+)
+_OptionalJournalS3ExportDescriptionTypeDef = TypedDict(
+    "_OptionalJournalS3ExportDescriptionTypeDef",
+    {
+        "OutputFormat": OutputFormatType,
+    },
+    total=False,
+)
+
+
+class JournalS3ExportDescriptionTypeDef(
+    _RequiredJournalS3ExportDescriptionTypeDef, _OptionalJournalS3ExportDescriptionTypeDef
+):
+    pass
+
+
+DescribeJournalS3ExportResponseTypeDef = TypedDict(
+    "DescribeJournalS3ExportResponseTypeDef",
+    {
+        "ExportDescription": JournalS3ExportDescriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListJournalS3ExportsForLedgerResponseTypeDef = TypedDict(
+    "ListJournalS3ExportsForLedgerResponseTypeDef",
+    {
+        "JournalS3Exports": List[JournalS3ExportDescriptionTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListJournalS3ExportsResponseTypeDef = TypedDict(
+    "ListJournalS3ExportsResponseTypeDef",
+    {
+        "JournalS3Exports": List[JournalS3ExportDescriptionTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
